from datetime import datetime


def get_dict_from_locals(locals_dict: dict, replace_underscore: bool = False, exclude: list = None):
    exclude = ('self', ) if exclude is None else tuple(['self'] + exclude)
    return {key if replace_underscore else key: value for key, value in
            locals_dict.items() if key not in exclude and '__py' not in key and value is not None}


def get_date_from_timestamp(date):
    return None if date is None else datetime.fromtimestamp(date)



from .category import Cron, Secrets, User, Users, Repos, Template, Builds
from .session import Session


class DroneApi(Session):

    @property
    def cron(self):
        return Cron(self)

    @property
    def secrets(self):
        return Secrets(self)

    @property
    def user(self):
        return User(self)

    @property
    def users(self):
        return Users(self)

    @property
    def repos(self):
        return Repos(self)

    @property
    def templates(self):
        return Template(self)

    @property
    def builds(self):
        return Builds(self)



import json
from datetime import datetime


class DroneCron:
    __attr__ = ('name', 'expr', 'branch')

    def __init__(self, data: dict):
        self._data = data

    @property
    def name(self):
        return self._data.get('name')

    @name.setter
    def name(self, new_name: str):
        self._data['name'] = new_name

    @property
    def expr(self):
        return self._data.get('expr')

    @expr.setter
    def expr(self, new_expression: str):
        self._data['expr'] = new_expression

    @property
    def branch(self):
        return self._data.get('branch', 'master')

    @branch.setter
    def branch(self, new_branch: str):
        self._data['branch'] = new_branch

    @property
    def next_execution(self):
        data = self._data.get('next')
        return datetime.utcfromtimestamp(data) if data else 'Next cron execution not set'

    @property
    def repo_id(self):
        return self._data.get('repo_id')

    def update_cron(self, new_cron: dict):
        self.name = new_cron.get('name')
        self.expr = new_cron.get('expr')
        self.branch = new_cron.get('branch')

    def to_dict(self):
        return {key: self.__getattribute__(key) for key in DroneCron.__attr__}

    def to_json(self):
        return json.dumps(self.to_dict())



from typing import List

from drone_api_client.service import get_date_from_timestamp


class Build:
    def __init__(self, data: dict):
        if data is not None:
            self.id: int = data.get('id')
            self.repo_id: int = data.get('repo_id')
            self.trigger: str = data.get('trigger')
            self.number: int = data.get('number')
            self.status: str = data.get('status')
            self.event: str = data.get('event')
            self.action: str = data.get('action')
            self.link: str = data.get('link')
            self.timestamp: int = get_date_from_timestamp(data.get('timestamp'))
            self.message: str = data.get('message')
            self.before: str = data.get('before')
            self.after: str = data.get('after')
            self.ref: str = data.get('ref')
            self.source_repo: str = data.get('source_repo')
            self.source: str = data.get('source')
            self.target: str = data.get('target')
            self.author_login: str = data.get('author_login')
            self.author_name: str = data.get('author_name')
            self.author_email: str = data.get('author_email')
            self.author_avatar: str = data.get('author_avatar')
            self.sender: str = data.get('sender')
            self.cron: str = data.get('cron')
            self.started: int = get_date_from_timestamp(data.get('started'))
            self.finished: int = get_date_from_timestamp(data.get('finished'))
            self.created: int = get_date_from_timestamp(data.get('created'))
            self.updated: int = get_date_from_timestamp(data.get('updated'))
            self.version: int = data.get('version')
            if data.get('stages') is not None:
                self.stages = tuple(Stages(stage) for stage in data.get('stages'))

    def __str__(self):
        return f'{self.message}, {self.status}'


class Stages:
    def __init__(self, data: dict):
        if data is not None:
            self.id: int = data.get('id')
            self.repo_id: int = data.get('repo_id')
            self.build_id: int = data.get('build_id')
            self.number: int = data.get('number')
            self.name: str = data.get('name')
            self.kind: str = data.get('kind')
            self.type: str = data.get('type')
            self.status: str = data.get('status')
            self.errignore: bool = data.get('errignore')
            self.exit_code: int = data.get('exit_code')
            self.machine: str = data.get('machine')
            self.os: str = data.get('os')
            self.arch: str = data.get('arch')
            self.started: int = get_date_from_timestamp(data.get('started'))
            self.stopped: int = get_date_from_timestamp(data.get('stopped'))
            self.created: int = get_date_from_timestamp(data.get('created'))
            self.updated: int = get_date_from_timestamp(data.get('updated'))
            self.version: int = data.get('version')
            self.on_success: bool = data.get('on_success')
            self.on_failure: bool = data.get('on_failure')
            if data.get('steps') is not None:
                self.steps: List[Steps] = tuple(Steps(step) for step in data.get('steps'))

    def __str__(self):
        return self.name


class Steps:
    def __init__(self, data: dict):
        if data is not None:
            self.id: int = data.get('id')
            self.step_id: int = data.get('step_id')
            self.number: int = data.get('number')
            self.name: str = data.get('name')
            self.status: str = data.get('status')
            self.exit_code: int = data.get('exit_code')
            self.started: int = get_date_from_timestamp(data.get('started'))
            self.stopped: int = get_date_from_timestamp(data.get('stopped'))
            self.version: int = data.get('version')

    def __str__(self):
        return self.name



import json
from datetime import datetime


class DroneUser:
    __attr__ = ('id', 'login', 'email', 'avatar', 'active', 'admin', 'machine', 'syncing', 'synced',
                'created', 'updated', 'last_login')

    def __init__(self, data: dict):
        self._data = data

    @property
    def id(self):
        return self._data.get('id')

    @property
    def login(self):
        return self._data.get('login')

    @property
    def email(self):
        return self._data.get('email')

    @email.setter
    def email(self, new_email: str):
        self._data['email'] = new_email

    @property
    def avatar(self):
        return self._data.get('avatar')

    @avatar.setter
    def avatar(self, link_to_avatar: str):
        self._data['avatar'] = link_to_avatar

    @property
    def active(self):
        return self._data.get('active')

    @property
    def admin(self):
        return self._data.get('admin', False)

    @property
    def machine(self):
        return self._data.get('machine')

    @property
    def syncing(self):
        return self._data.get('syncing')

    @property
    def synced(self):
        return datetime.utcfromtimestamp(self._data['synced']) if self._data.get('synced') else None

    @property
    def created(self):
        return datetime.utcfromtimestamp(self._data['created']) if self._data.get('created') else None

    @property
    def updated(self):
        return datetime.utcfromtimestamp(self._data['updated']) if self._data.get('updated') else None

    @property
    def last_login(self):
        return datetime.utcfromtimestamp(self._data['last_login']) if self._data.get('last_login') else None

    def to_dict(self):
        return {key: self.__getattribute__(key) for key in DroneUser.__attr__}

    def to_json(self):
        return json.dumps(self.to_dict())

    def to_create(self):
        return {key: self.__getattribute__(key) for key in ('login', 'email', 'admin', 'avatar')
                if self.__getattribute__(key) is not None}



import json


class DroneRepo:
    __attr__ = ('id', 'uid', 'user_id', 'namespace', 'name', 'slug', 'scm', 'git_http_url', 'git_ssh_url',
                'link', 'default_branch', 'private', 'visibility', 'active', 'config_path', 'trusted',
                'protected', 'ignore_forks', 'ignore_pull_requests', 'timeout', 'counter', 'synced',
                'created', 'updated', 'version', 'permissions')

    __change__ = ('config_path', 'protected', 'trusted', 'timeout', 'visibility', 'ignore_forks',
                  'ignore_pull_requests')

    def __init__(self, data: dict):
        self._data = data

    @property
    def id(self):
        return self._data.get('id')

    @property
    def uid(self):
        return self._data.get('uid')

    @property
    def user_id(self):
        return self._data.get('user_id')

    @property
    def namespace(self):
        return self._data.get('namespace')

    @property
    def name(self):
        return self._data.get('name')

    @property
    def slug(self):
        return self._data.get('slug')

    @property
    def scm(self):
        return self._data.get('scm')

    @property
    def git_http_url(self):
        return self._data.get('git_http_url')

    @property
    def git_ssh_url(self):
        return self._data.get('git_ssh_url')

    @property
    def link(self):
        return self._data.get('link')

    @property
    def default_branch(self):
        return self._data.get('default_branch')

    @property
    def private(self):
        return self._data.get('private')

    @property
    def visibility(self):
        return self._data.get('visibility')

    @property
    def active(self):
        return self._data.get('active')

    @property
    def config_path(self):
        return self._data.get('config_path')

    @property
    def trusted(self):
        return self._data.get('trusted')

    @property
    def protected(self):
        return self._data.get('protected')

    @property
    def ignore_forks(self):
        return self._data.get('ignore_forks')

    @property
    def ignore_pull_requests(self):
        return self._data.get('ignore_pull_requests')

    @property
    def timeout(self):
        return self._data.get('timeout')

    @property
    def counter(self):
        return self._data.get('counter')

    @property
    def synced(self):
        return self._data.get('synced')

    @property
    def created(self):
        return self._data.get('created')

    @property
    def updated(self):
        return self._data.get('updated')

    @property
    def version(self):
        return self._data.get('version')

    @property
    def permissions(self):
        return self._data.get('permissions')

    def update(self, upd: dict):
        for key, value in upd.items():
            if key in DroneRepo.__change__:
                self._data[key] = value

    def to_dict(self):
        return {key: self.__getattribute__(key) for key in DroneRepo.__attr__}

    def to_json(self):
        return json.dumps(self.to_dict())



import json

import requests


class Session:
    def __init__(self, host: str, token: str, repo: str = ''):
        self.repo = repo
        self.__host = f"{host.replace('/api', '')}/api"
        self._session = requests.Session()
        self._session.headers.update({
            'Authorization': f'Bearer {token}'
        })

    def request(self, method: str, url: str, add_repo: bool = True, data: dict = None, params: dict = None, **kwargs):
        host = f"{self.__host}/repos/{self.repo}" if add_repo else self.__host
        data = json.dumps(data) if data else ''
        response = self._session.request(method=method, url=f'{host}{url}', data=data, params=params, **kwargs)
        if response.status_code in (200, 201):
            return response.json()
        else:
            return f'Error: {response.status_code}: {response.reason} ({response.text})'



import json
from typing import List

from drone_api_client.model.cron import DroneCron
from .model.build import Build
from .model.repos import DroneRepo
from .model.secrets import DroneSecret
from .model.template import DroneTemplate
from .model.user import DroneUser
from .service import get_dict_from_locals
from .session import Session


class Base:
    def __init__(self, session):
        self._session: Session = session

    def _valid(self, response, return_class, key: str = None, add_session: bool = False):
        if isinstance(response, str):
            return response
        elif key:
            return return_class(response[key]) if isinstance(response[key], dict) else \
                [return_class(elem) for elem in response[key]]
        else:
            if add_session:
                return return_class(self, response) if isinstance(response, dict) else \
                    [return_class(self, elem) for elem in response]
            else:
                return return_class(response) if isinstance(response, dict) else [return_class(elem) for elem in
                                                                                  response]


class Cron(Base):
    def create_cron(self, name: str, expr: str, branch: str = 'master') -> DroneCron:
        """
        https://docs.drone.io/api/cron/cron_create/

        Create a new cron job. Please note this api requires write access to the repository
        :param name: name of cron job
        :param expr: cron expression
        :param branch: branch were cron will be runs
        :return: DroneCron object with created cron job
        """
        data = get_dict_from_locals(locals())
        return self._valid(self._session.request('post', '/cron', data=data), DroneCron)

    def delete_cron(self, cron_name: str) -> None:
        """
        https://docs.drone.io/api/cron/cron_delete/

        Deletes a cron job. Please note this api requires write access to the repository
        :param cron_name: existing cron in repository
        :return: None
        """
        return self._session.request('delete', f'/cron/{cron_name}')

    def get_cron_info(self, cron_name: str) -> DroneCron:
        """
        https://docs.drone.io/api/cron/cron_info/

        Returns the named cron job. Please note this api requires write access to the repository
        :param cron_name: existing cron name
        :return: DroneCron object if cron exists
        """
        return self._valid(self._session.request('get', f'/cron/{cron_name}'), DroneCron)

    def get_cron_list(self) -> List[DroneCron]:
        """
        https://docs.drone.io/api/cron/cron_list/

        Returns the cron job list. Please note this api requires write access to the repository
        :return: Returns list of all cron jobs in repository
        """
        return self._valid(self._session.request('get', '/cron'), DroneCron)

    def execute(self, cron_name: str) -> DroneCron:
        """
        https://docs.drone.io/api/cron/cron_trigger/

        Trigger an existing cron task. Please note this api requires write access to the repository
        :param cron_name: existing cron name
        :return: executed cron
        """
        return self._valid(self._session.request('post', f'/cron/{cron_name}'), DroneCron)

    def update_cron(self, name: str, expr: str = None, branch: str = None) -> DroneCron:
        """
        https://docs.drone.io/api/cron/cron_update/

        Updates the named cron job. Please note this api requires write access to the repository
        :param name: existing crone name
        :param expr: new cron expression. Optional
        :param branch: new branch. Optional
        :return: Updated cron
        """
        cron = self.get_cron_info(name)
        if isinstance(cron, (list, tuple)):
            return "Cron expression with given name doesn't found"
        cron.expr = expr if expr else cron.expr
        cron.branch = branch if branch else cron.branch
        return self._valid(self._session.request('patch', f'/cron/{name}', data=cron.to_dict()), DroneCron)


class Secrets(Base):
    def create(self, name: str, data: str, pull_request: bool = True) -> DroneSecret:
        """
        https://docs.drone.io/api/secrets/secret_create/

        Create a new repository secret. Please note this api requires write access to the repository
        :param name: new secret name
        :param data: data for secret
        :param pull_request:
        :return: DroneSecret object with created secret
        """
        data = get_dict_from_locals(locals(), exclude=['name'])
        return self._valid(self._session.request('post', '/secrets', data=data), DroneSecret)

    def delete(self, secret_name: str) -> None:
        """
        https://docs.drone.io/api/secrets/secret_delete/

        Deletes a repository secret. Please note this api requires write access to the repository
        :param secret_name:
        :return: None
        """
        return self._session.request('delete', f'/secrets/{secret_name}')

    def get_secret_info(self, secret_name: str) -> DroneSecret:
        """
        https://docs.drone.io/api/secrets/secret_info/

        Returns the repository secret.
        Please note this api requires write access to the repository,
        and the request parameter {secret} is not the secret’s id but secret name
        :param secret_name: existing secret name
        :return: DroneSecret object if secrets found in repository
        """
        return self._valid(self._session.request('get', f'/secrets/{secret_name}'), DroneSecret)

    def get_secrets(self) -> List[DroneSecret]:
        """
        https://docs.drone.io/api/secrets/secret_list/

        Returns the repository secret list. Please note this api requires write access to the repository
        :return: List of DroneSecret in repo
        """
        return self._valid(self._session.request('get', '/secrets'), DroneSecret)

    def update_secret(self, secret_name: str, data: str = None, pull_request: bool = None) -> DroneSecret:
        """
        https://docs.drone.io/api/secrets/secret_update/

        Updates the specified repository secret.
        Please note this api requires write access to the repository,
        and the request parameter {secret} is not the secret’s id but secret name.
        :param secret_name: existing secret
        :param data: new data in secret
        :param pull_request: bool value
        :return: DroneSecret object
        """

        secret = self.get_secret_info(secret_name)
        if isinstance(secret, (list, tuple)):
            return "Secret with given name doesn't found"
        data = get_dict_from_locals(locals(), exclude=['name'])
        return self._valid(self._session.request('patch', f'/secrets/{secret.name}', data=data), DroneSecret)


class User(Base):
    def get_user_builds(self) -> List[Build]:
        """
        https://docs.drone.io/api/user/user_builds/

        Returns the currently authenticated user’s build feed
        :return:
        """
        return self._valid(self._session.request('get', '/user/builds', add_repo=False), Build)

    def get_user_info(self) -> DroneUser:
        """
        https://docs.drone.io/api/user/user_info/

        Returns the currently authenticated user
        :return: Current drone user
        """
        return self._valid(self._session.request('get', '/user', add_repo=False), DroneUser)

    def get_user_repos(self) -> List[DroneRepo]:
        """
        https://docs.drone.io/api/user/user_repos/

        :return: Returns the currently authenticated user’s repository list
        """
        return self._valid(self._session.request('get', '/user/repos', add_repo=False), DroneUser)

    def sync_user_repos_list(self) -> None:
        """
        https://docs.drone.io/api/user/user_sync/

        Synchronize the currently authenticated user’s repository list.
        :return: None
        """
        self._session.request('post', '/user/repos', add_repo=False)


class Users(Base):
    def create_user(self, login: str, email: str, active: bool = True, avatar_url: str = '') -> DroneUser:
        """
        https://docs.drone.io/api/users/users_create/

        Creates a user. Please note this api requires administrative privileges.
        :param login: login for new user
        :param email: email for new user
        :param active: is active user. Default is True
        :param avatar_url: link to user avatar. Default is ''
        :return: created user
        """
        data = DroneUser(get_dict_from_locals(locals())).to_create()
        return self._valid(self._session.request('post', '/users', data=data, add_repo=False), DroneUser)

    def delete_user(self, login: str) -> None:
        """
        https://docs.drone.io/api/users/users_delete/

        Deletes a user. Please note this api requires administrative privileges.
        :param login: existing user login
        :return: None
        """
        self._session.request('delete', f'/users/{login}', add_repo=False)

    def get_user_info(self, login: str) -> DroneUser:
        """
        https://docs.drone.io/api/users/users_info/

        Returns information about the named registered user. Please note this api requires administrative privileges.
        :param login: existing user login
        :return: DroneUser object with user
        """
        return self._valid(self._session.request('get', f'/users/{login}', add_repo=False), DroneUser)

    def get_users_list(self) -> List[DroneUser]:
        """
        https://docs.drone.io/api/users/users_list/

        Returns a list of all registered users. Please note this api requires administrative privileges.
        :return: List of users
        """
        return self._valid(self._session.request('get', '/users', add_repo=False), DroneUser)


class Repos(Base):
    def disable_repo(self, repo_name: str) -> DroneRepo:
        """
        https://docs.drone.io/api/repos/repo_delete/

        Permanently deletes a repository. It cannot be undone.
        Please note this api requires administrative access to the repository,
        and repository’s secrets and builds aren’t deleted
        :param repo_name: existing repo name
        :return: DroneRepo object
        """
        return self._valid(self._session.request('delete', f'/repos/{repo_name}', add_repo=False), DroneRepo)

    def enable_repo(self, repo_name: str) -> DroneRepo:
        """
        https://docs.drone.io/api/repos/repo_create/

        Registers a named repository with Drone. Please note this api requires administrative access to the repository
        :param repo_name: existing repo name
        :return: DroneRepo object
        """
        return self._valid(self._session.request('post', f'/repos/{repo_name}', add_repo=False), DroneRepo)

    def get_repo_info(self, repo_name: str) -> DroneRepo:
        """
        https://docs.drone.io/api/repos/repo_info/

        Retrieves the details of a repository. Please note this api requires read access to the repository.
        :param repo_name: existing repository name
        :return: DroneRepo object
        """
        return self._valid(self._session.request('get', f'/repos/{repo_name}', add_repo=False), DroneRepo)

    def repo_list(self) -> List[DroneRepo]:
        """
        https://docs.drone.io/api/repos/repo_list/

        :return: repositories which are registered to Drone
        """
        return self._valid(self._session.request('get', '/user/repos', add_repo=False), DroneRepo)

    def repair_repo(self, repo_name: str) -> None:
        """
        https://docs.drone.io/api/repos/repo_repair/

        Recreates webhooks for your repository in your version control system (e.g GitHub).
        This can be used if you accidentally delete your webhooks.
        Please note this api requires administrative access to the repository
        :param repo_name: existing repo name
        :return: None
        """
        return self._valid(self._session.request('post', f'/repos/{repo_name}/repair', add_repo=False), DroneRepo)

    def update(self, repo_name: str, dict_with_update: dict) -> DroneRepo:
        """
        https://docs.drone.io/api/repos/repo_update/

        Updates a named repository. Please note this api requires administrative access to the repository
        :param repo_name: existing repo name
        :param dict_with_update: dict with updated parameters
        :return: updated DroneRepo object
        """
        repos = self.get_repo_info(repo_name)
        if isinstance(repos, (list, tuple)):
            return f"Can't find {repo_name}"
        else:
            data = json.dumps({key: value for key, value in dict_with_update if key in DroneRepo.__change__})
            return self._valid(self._session.request('patch', f'/repos/{repo_name}', add_repo=False, data=data),
                               DroneRepo)


class Template(Base):
    def create(self, name: str, data: str, namespace: str) -> DroneTemplate:
        """
        https://docs.drone.io/api/templates/template_create/

        Create a new template. Please note this api requires write access to the repository
        :param name: template name
        :param data: template data
        :param namespace: template namespace
        :return: DroneTemplate object
        """
        data = get_dict_from_locals(locals())
        return self._valid(self._session.request('post', '/templates', data=data, add_repo=False), DroneTemplate)

    def delete(self, namespace: str, name: str) -> None:
        """
        https://docs.drone.io/api/templates/template_delete/

        Deletes a template. Please note this api requires write access to the repository
        :param namespace: existing namespace name
        :param name: existing template name
        :return: None
        """
        self._session.request('delete', f'/templates/{namespace}/{name}', add_repo=False)

    def get_template_info(self, namespace: str, name: str) -> DroneTemplate:
        """
        https://docs.drone.io/api/templates/template_info/

        Returns the template. Please note this api requires write access to the repository
        :param namespace: existing namespace name
        :param name: existing template name
        :return:
        """
        return self._valid(self._session.request('get', f'/templates/{namespace}/{name}', add_repo=False),
                           DroneTemplate)

    def get_template_list(self, namespace: str):
        """
        https://docs.drone.io/api/templates/template_list/

        Returns the organization template list. Please note this api requires write access to the repository
        :return:
        """
        return self._valid(self._session.request('get', f'/templates/{namespace}', add_repo=False), DroneTemplate)


class Builds(Base):
    def build_approve(self, build_number: int):
        """
        https://docs.drone.io/api/builds/build_approve/

        Approves a blocked build. Please note this api requires write access to the repository,
        and the request parameter {build} is not the build id but the build number.
        :param build_number: is not the build id but the build number.
        :return:
        """
        self._session.request('post', f'/builds/{build_number}/approve')

    def build_decline(self, build_number: int):
        """
        https://docs.drone.io/api/builds/build_approve/

        Declines a blocked build. Please note this api requires write access to the repository,
        and the request parameter {build} is not the build id but the build number.
        :param build_number: is not the build id but the build number.
        :return:
        """
        self._session.request('post', f'/builds/{build_number}/decline')

    def build_info(self, build_number: int) -> Build:
        """
        https://docs.drone.io/api/builds/build_info/

        Returns the specified repository build. Please note this api requires read access to the repository
        and the request parameter {build} is not the build id but the build number.
        :param build_number: is not the build id but the build number.
        :return:
        """
        return self._valid(self._session.request('get', f'/builds/{build_number}'), Build)

    def build_list(self) -> List[Build]:
        """
        https://docs.drone.io/api/builds/build_list/

        Returns recent builds for the repository based on name.
        Please note this api requires read access to the repository

        :return:
        """
        return self._valid(self._session.request('get', '/builds'), Build)

    def build_logs(self, build_number: int):
        """
        https://docs.drone.io/api/builds/build_logs/

        Please note this api requires read access to the repository
        :param build_number: is not the build id but the build number.
        :return:
        """
        return self._session.request('get', f'/builds/{build_number}/logs/')

    def build_restart(self, build_number: int) -> Build:
        """
        https://docs.drone.io/api/builds/build_start/

        Restart the specified build. Please note this api requires read and write access to the repository
        and the request parameter {build} is not the build id but the build number.
        :param build_number: is not the build id but the build number.
        :return:
        """
        return self._valid(self._session.request('post', f'/builds/{build_number}'), Build)

    def build_stop(self, build_number: int) -> Build:
        """
        https://docs.drone.io/api/builds/build_stop/

        Stop the specified build. Please note this api requires administrative privileges
        and the request parameter {build} is not the build id but the build number.
        :param build_number: is not the build id but the build number.
        :return:
        """
        return self._valid(self._session.request('delete', f'/builds/{build_number}'), Build)



import setuptools
from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='drone-api-client',
    version='0.2.3',
    use_scm_version=False,
    description='Drone Api Python Client',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Biriukov Maksym',
    author_email='maximbirukov77@gmail.com',
    url="https://github.com/Slamnlc/drone-api-client",
    download_url='https://github.com/Slamnlc/drone-api-client/archive/refs/tags/v0.2.3.tar.gz',
    packages=setuptools.find_packages(exclude=("tests", "dev_tools")),
    install_requires=[
        'requests'
    ],
    entry_points={
        "drone_api": [
            "drone-api-client = drone_api_client.drone_api_client",
        ]
    },
)



class DroneTemplate:
    __attr__ = ('id', 'name', 'namespace', 'data')

    def __init__(self, data: dict):
        self._data = data

    @property
    def id(self):
        return self._data.get('id')

    @property
    def name(self):
        return self._data.get('name')

    @property
    def namespace(self):
        return self._data.get('namespace')

    @property
    def data(self):
        return self._data.get('data')
